@@ -5,7 +5,7 @@ from pm4py.util.constants import CASE_CONCEPT_NAME
 from pm4py.algo.filtering.common.timestamp.timestamp_common import get_dt_from_string
 from pm4py.util.xes_constants import DEFAULT_TIMESTAMP_KEY
 from pm4py.util.constants import PARAMETER_CONSTANT_TIMESTAMP_KEY, PARAMETER_CONSTANT_CASEID_KEY
-from pm4py.util.versions import check_pandas_ge_024
+from pm4py.util.vers_checker import check_pandas_ge_024
 from enum import Enum
 from pm4py.util import exec_utils
 
