@@ -1,2 +1,6 @@
 from pm4py.objects import log, petri, transition_system, conversion, process_tree, heuristics_net, random_variables, \
     stochastic_petri, dfg
+import pkgutil
+
+if pkgutil.find_loader("networkx"):
+    from pm4py.objects import bpmn
