@@ -2,6 +2,7 @@ import shutil
 
 from pm4py.util.vis_utils import human_readable_stat, get_arc_penwidth, get_trans_freq_color, get_base64_from_gviz, \
     get_base64_from_file
+from pm4py.util import vis_utils
 
 
 def save(gviz, output_file_path):
@@ -28,19 +29,7 @@ def view(gviz):
     gviz
         GraphViz diagram
     """
-    is_ipynb = False
-
-    try:
-        get_ipython()
-        is_ipynb = True
-    except NameError:
-        # we are not inside Jupyter, do nothing
-        pass
-
-    if is_ipynb:
-        from IPython.display import Image
-        image = Image(gviz.render())
-        from IPython.display import display
-        return display(image)
+    if vis_utils.check_visualization_inside_jupyter():
+        vis_utils.view_image_in_jupyter(gviz.render())
     else:
         return gviz.view(cleanup=True)
